package com.vendor.platform.ui;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.api.IDeviceChangedListener;
import com.vendor.platform.api.IDeviceManager;
import com.vendor.platform.api.chips.Chip;
import com.vendor.platform.api.chips.Chips;
import com.vendor.platform.core.internal.DeviceManager;
import com.vendor.platform.ui.PlatformUIActivator;
import com.vendor.platform.ui.ToolUtils;
import com.vendor.platform.ui.internal.IniUtils;
import com.vendor.platform.ui.internal.PerspectiveUtil;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.runtime.FileLocator;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.graphics.Cursor;
import org.eclipse.swt.graphics.Device;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Layout;
import org.eclipse.ui.part.ViewPart;
import org.osgi.framework.Bundle;

public class WelcomeView extends ViewPart implements IDeviceChangedListener {
  private static final String TOOL_PROPERTIES = "TOOL.PROPERTIES";
  
  private static final String TOOL_PROPERTIES_KEY_EN = "DESCRIPTION_EN";
  
  private static final String TOOL_PROPERTIES_KEY_CN = "DESCRIPTION_CN";
  
  private static com.vendor.platform.ui.WelcomeView INSTANCE = null;
  
  public static final String ID = "com.vendor.platform.ui.view.welcome";
  
  private Composite subPanel;
  
  private Map<String, Control> map = new HashMap<>();
  
  private Map<String, Image> toolImageMap = new HashMap<>();
  
  private String nl;
  
  private Cursor wait = new Cursor(null, 1);
  
  public static final Map<String, Integer> READED_BUNDLES = new HashMap<>();
  
  public WelcomeView() {
    DeviceManager.getInstance().addDeviceChangedListener(this);
    this.nl = IniUtils.getIniConfiguration("osgi.nl");
    if (this.nl.length() == 0) {
      this.nl = Locale.getDefault().toString();
      if (!this.nl.equals(Locale.US.toString()) && 
        !this.nl.equals(Locale.SIMPLIFIED_CHINESE.toString()))
        if (this.nl.startsWith("en_")) {
          this.nl = Locale.US.toString();
        } else if (this.nl.startsWith("zh_")) {
          this.nl = Locale.SIMPLIFIED_CHINESE.toString();
        }  
    } 
    registerView(this);
  }
  
  public static com.vendor.platform.ui.WelcomeView getInstance() {
    return INSTANCE;
  }
  
  public static void registerView(com.vendor.platform.ui.WelcomeView view) {
    INSTANCE = view;
  }
  
  public static void unregisterView() {
    INSTANCE = null;
  }
  
  public void createPartControl(Composite parent) {
    parent.setLayout((Layout)new FillLayout());
    ScrolledComposite panel = new ScrolledComposite(parent, 768);
    this.subPanel = new Composite((Composite)panel, 0);
    panel.setContent((Control)this.subPanel);
    this.subPanel.setLayoutData(new GridData(1808));
    GridLayout gridLayout = new GridLayout(3, true);
    gridLayout.marginWidth = 60;
    this.subPanel.setLayout((Layout)gridLayout);
    panel.setExpandHorizontal(true);
    panel.setExpandVertical(true);
    panel.setMinWidth(800);
    panel.setMinHeight(600);
    ImageDescriptor imageDescriptor = PlatformUIActivator.getImageDescriptor("icons/welcome.bmp");
    if (imageDescriptor != null)
      this.subPanel.setBackgroundImage(imageDescriptor.createImage()); 
    this.subPanel.setBackgroundMode(1);
    Label topspace = new Label(this.subPanel, 0);
    topspace.setVisible(false);
    GridData gd = new GridData(768);
    gd.horizontalSpan = 3;
    gd.heightHint = 200;
    topspace.setLayoutData(gd);
    try {
      initButton();
    } catch (Exception exception) {}
  }
  
  private void initButton() {
    refreshPerspectiveButton(READED_BUNDLES);
  }
  
  public synchronized void refreshPerspectiveButton(Map<String, Integer> needUpdatePerspectiveIDS) {
    if (needUpdatePerspectiveIDS != null && needUpdatePerspectiveIDS.size() > 0)
      Display.getDefault().syncExec((Runnable)new Object(this, needUpdatePerspectiveIDS)); 
  }
  
  private Control createImageLink(ToolModel toolModel) {
    return (Control)new ImageLink(this, this.subPanel, 0, toolModel);
  }
  
  private void openBurnToolViewOrWelcomeView() {
    Chips chips = DeviceManager.getCurrentChips();
    IDeviceManager dm = DeviceManager.getInstance();
    ArrayList<String> suiltableToolIDs = chips.getSuitableToolIDs(dm.getCurrentDevice());
    if ("Flasher".equals(suiltableToolIDs.get(0))) {
      this.subPanel.layout(false);
      try {
        PerspectiveUtil.openPerspectiveOnTheRight("com.vendor.burn.perspectives.FastbootPerspective");
      } catch (ExecutionException e) {
        return;
      } 
    } else {
      this.subPanel.layout(true);
    } 
  }
  
  private File findFile(Bundle bundle, String path) {
    URL entry = bundle.getEntry(path);
    try {
      URL fileURL = FileLocator.toFileURL(entry);
      return new File(fileURL.getFile());
    } catch (Exception e) {
      e.printStackTrace();
      return null;
    } 
  }
  
  public void setFocus() {
    ToolUtils.disableDetach("com.vendor.platform.ui.view.welcome");
  }
  
  public ToolModel computeToolModel(Bundle bundle) {
    ToolModel toolModel = new ToolModel();
    Image image = null;
    if (this.toolImageMap.get(bundle.getSymbolicName()) == null) {
      File imageFile = findFile(bundle, "TOOL.PNG");
      if (imageFile != null && imageFile.exists()) {
        FileInputStream input = null;
        try {
          input = new FileInputStream(imageFile);
          image = new Image((Device)getViewSite().getShell().getDisplay(), input);
          this.toolImageMap.put(bundle.getSymbolicName(), image);
        } catch (FileNotFoundException fileNotFoundException) {
        
        } finally {
          if (input != null)
            try {
              input.close();
            } catch (IOException iOException) {} 
        } 
      } 
    } else {
      image = this.toolImageMap.get(bundle.getSymbolicName());
    } 
    if (image == null)
      image = PlatformUIActivator.getToolDefaultImage(); 
    String desc = "";
    File propertiesFile = findFile(bundle, "TOOL.PROPERTIES");
    if (propertiesFile != null && propertiesFile.exists()) {
      FileInputStream input = null;
      try {
        input = new FileInputStream(propertiesFile);
        Properties prop = new Properties();
        prop.load(input);
        if (this.nl.equals(Locale.US.toString())) {
          if (prop.getProperty("DESCRIPTION_EN") != null)
            desc = prop.getProperty("DESCRIPTION_EN"); 
        } else if (this.nl.equals(Locale.SIMPLIFIED_CHINESE.toString()) && 
          prop.getProperty("DESCRIPTION_CN") != null) {
          desc = prop.getProperty("DESCRIPTION_CN");
        } 
      } catch (Exception e1) {
        e1.printStackTrace();
      } finally {
        if (input != null)
          try {
            input.close();
          } catch (IOException iOException) {} 
      } 
    } 
    toolModel.setImage(image);
    toolModel.setDescription(desc);
    return toolModel;
  }
  
  public void dispose() {
    unregisterView();
    DeviceManager.getInstance().removeDeviceChangedListener(this);
    super.dispose();
  }
  
  public void deviceChanged(Chip chip) {
    refreshPerspectiveButton(READED_BUNDLES);
  }
}
